@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -25,6 +25,7 @@ import java.rmi.RemoteException;
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Options;
 import com.openexchange.advertisement.RemoteAdvertisementService;
+import com.openexchange.auth.Credentials;
 import com.openexchange.auth.rmi.RemoteAuthenticator;
 import com.openexchange.cli.AbstractRmiCLI;
 
@@ -63,8 +64,11 @@ public class RemoveAdvertisementConfigs extends AbstractRmiCLI<Void> {
 
     @Override
     protected Void invoke(Options options, CommandLine cmd, String optRmiHostName) throws Exception {
+        String adminUser = cmd.getOptionValue('A');
+        String adminPassword = cmd.getOptionValue('P');
+
         RemoteAdvertisementService rmiService = getRmiStub(optRmiHostName, RemoteAdvertisementService.RMI_NAME);
-        rmiService.removeConfigurations(reseller, clean, includePreview);
+        rmiService.removeConfigurations(reseller, clean, includePreview, new Credentials(adminUser, adminPassword));
         return null;
     }
 
