@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -33,6 +33,8 @@ import com.openexchange.advertisement.AdvertisementPackageService;
 import com.openexchange.advertisement.RemoteAdvertisementService;
 import com.openexchange.advertisement.impl.osgi.Services;
 import com.openexchange.advertisement.impl.services.AbstractAdvertisementConfigService;
+import com.openexchange.auth.Authenticator;
+import com.openexchange.auth.Credentials;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheService;
 import com.openexchange.database.DatabaseService;
@@ -40,6 +42,7 @@ import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.reseller.ResellerService;
 import com.openexchange.reseller.data.ResellerAdmin;
+import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
@@ -66,7 +69,12 @@ public class RemoteAdvertisementServiceImpl implements RemoteAdvertisementServic
     private static final String SQL_SELECT_CONFIGIDS_FROM_MAPPING_WHERE = "SELECT configId FROM advertisement_mapping WHERE reseller=?;";
 
     @Override
-    public void removeConfigurations(String reseller, boolean clean, boolean includePreview) throws OXException {
+    public void removeConfigurations(String reseller, boolean clean, boolean includePreview, Credentials auth) throws OXException {
+        Authenticator authenticator = Services.optService(Authenticator.class);
+        if (authenticator == null) {
+            throw ServiceExceptionCode.SERVICE_UNAVAILABLE.create("Authenticator missing.");
+        }
+        authenticator.doAuthentication(auth);
 
         List<String> activeResellerNames = null;
         if (clean) {
@@ -244,8 +252,5 @@ public class RemoteAdvertisementServiceImpl implements RemoteAdvertisementServic
                 }
             }
         }
-
-
     }
-
 }
