@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -303,8 +303,8 @@ public abstract class AbstractAdvertisementConfigService implements Advertisemen
 
             ConfigResult configResult = null;
             try {
-                if (property.isDefined()) {
-                    String value = property.get();
+                String value = property.get();
+                if (value != null) {
                     int configId = Integer.parseInt(value);
                     if (config == null) {
                         stmt = con.prepareStatement(SQL_DELETE_CONFIG);
