@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -23,6 +23,7 @@ package com.openexchange.advertisement;
 
 import java.rmi.Remote;
 import java.rmi.RemoteException;
+import com.openexchange.auth.Credentials;
 import com.openexchange.exception.OXException;
 
 /**
@@ -39,8 +40,11 @@ public interface RemoteAdvertisementService extends Remote {
      * Removes all configurations and mapping for the given reseller. If the given reseller is null, all configurations and mapping are deleted instead.
      * 
      * @param reseller The name of the reseller
+     * @param clean
+     * @param includePreview
+     * @param auth Credentials for authenticating against server.
      * @throws OXException
      */
-    public void removeConfigurations(String reseller, boolean clean, boolean includePreview) throws OXException, RemoteException;
+    public void removeConfigurations(String reseller, boolean clean, boolean includePreview, Credentials auth) throws OXException, RemoteException;
 
 }
